package adminkindboxhandler

import (
	"net/http"

	param "git.gocasts.ir/ebhomengo/niki/param/admin/kind_box"
	httpmsg "git.gocasts.ir/ebhomengo/niki/pkg/http_msg"
	"github.com/labstack/echo/v4"
)

// Update godoc
// @Summary      Update kind Box by admin
// @Tags         Admins KindBoxes
// @Accept       json
// @Produce      json
// @Param        id path int true "Kind Box ID"
// @Param        Request body param.KindBoxUpdateRequest true "Update KindBox Request Body"
// @Success      204
// @Failure      400  {string}  "Bad Request"
// @Failure      401  {string}  "invalid or expired jwt"
// @Failure      403  {string}  "user not allowed"
// @Failure      422  {object}  httpmsg.ErrorResponse
// @Failure      500  {string}  "something went wrong"
// @Security 	 AuthBearerAdmin
// @Router       /admins/kindboxes/update/{id} [put].
func (h Handler) Update(c echo.Context) error {

	var req param.KindBoxUpdateRequest

	if bErr := c.Bind(&req); bErr != nil {
		return c.JSON(http.StatusBadRequest, httpmsg.ErrorResponse{
			Message: "Invalid request body",
		})
	}

	resp, sErr := h.adminKindBoxSvc.Update(c.Request().Context(), req)
	if sErr != nil {
		msg, code := httpmsg.Error(sErr)
		if resp.FieldErrors != nil {
			return c.JSON(code, echo.Map{
				"message": msg,
				"errors":  resp.FieldErrors,
			})
		}

		return echo.NewHTTPError(code, msg)
	}

	return c.JSON(http.StatusNoContent, nil)
}
