package agentkindboxservice

import (
	"context"

	param "git.gocasts.ir/ebhomengo/niki/param/agent/kind_box"
	richerror "git.gocasts.ir/ebhomengo/niki/pkg/rich_error"
)

func (s Service) Get(ctx context.Context, req param.GetKindBoxRequest) (param.GetKindBoxResponse, error) {
	const op = "agentkindboxservice.Get"
	if fieldErrors, vErr := s.vld.ValidateGetRequest(ctx, req); vErr != nil {
		return param.GetKindBoxResponse{FieldErrors: fieldErrors}, richerror.New(op).WithErr(vErr)
	}
	kindBox, err := s.repo.GetAwaitingReturnByAgent(ctx, req.KindBoxID, req.AgentID)
	if err != nil {
		return param.GetKindBoxResponse{}, richerror.New(op).WithErr(err)
	}

	return param.GetKindBoxResponse{
		Data: param.Data{
			ID:                 kindBox.ID,
			KindBoxReqID:       kindBox.KindBoxReqID,
			BenefactorID:       kindBox.BenefactorID,
			KindBoxType:        kindBox.KindBoxType,
			Amount:             kindBox.Amount,
			SerialNumber:       kindBox.SerialNumber,
			Status:             kindBox.Status,
			DeliverReferTimeID: kindBox.DeliverReferTimeID,
			DeliverReferDate:   kindBox.DeliverReferDate,
			DeliverAddressID:   kindBox.DeliverAddressID,
			SenderAgentID:      kindBox.SenderAgentID,
			DeliveredAt:        kindBox.DeliveredAt,
			ReturnReferTimeID:  kindBox.ReturnReferTimeID,
			ReturnReferDate:    kindBox.ReturnReferDate,
			ReturnAddressID:    kindBox.ReturnAddressID,
			ReceiverAgentID:    kindBox.ReceiverAgentID,
			ReturnedAt:         kindBox.ReturnedAt,
		},
	}, nil
}
